/**
 * @program: kicc-ui
 * @description: 基础相关实体类
 * 类型定义
 * @author: wangxiang4
 * @create: 2022/4/8
 */

/** CAS统一认证用户模型 */
export interface CasUser {
  username: string;
  password: string;
  enabled: boolean;
  accountNonExpired: boolean;
  credentialsNonExpired: boolean;
  accountNonLocked: boolean;
  authorities: Recordable[];
  id: string;
  nickName: string;
  email: string;
  phone: string;
  sex: string;
  avatar: string;
  loginIp: string;
  loginTime: string;
  ssoStatus: string;
  ssoCreateById: string;
  ssoCreateByName: string;
  ssoCreateTime: string;
  ssoUpdateById: string;
  ssoUpdateByName: string;
  ssoUpdateTime: string;
  remarks: string;
  roleId: string;
  tenantId: string;
  exPrincipals: { [key: string]: string };
  [key: string]: any;
}

/** SSO扩展用户模型 */
export interface KiccUser extends CasUser {
  // 扩展用户ID
  id: string;
  // CAS用户ID
  casUserId: string;
  // 用户类型
  userType: string;
  // 所属部门ID
  deptId: string;
  // 所属部门名称
  deptName: string;
  // 地图标记点位置图片旋转值
  mapOrientation: number;
  // 地图设计器默认中心点位置
  mapCenter: string;
  // 用户状态
  status: string;
  // 指定登录后首页跳转
  homePath?: string;
  // 角色ID权限
  roleIds: string[];
  // 菜单按钮权限
  permissions: string[];
  // 多租户ID集合
  tenantIds: string[];
  // 创建ID
  createById: string;
  // 创建者
  createByName: string;
  // 创建时间
  createTime: string;
  // 更新ID
  updateById: string;
  // 更新人
  updateByName: string;
  // 更新时间
  updateTime: string;
  [key: string]: any;
}

/** 基础模型 */
export interface BaseEntity {
  tenantId: string;
  currentUser: KiccUser;
  sqlFilter: string;
}

/** 结果集模型 */
export interface ResultVo<T = any> {
  result: T;
  extend: T;
}
