import type { PushConcernFan, PushConcernFanParams, PushConcernFanResult } from '/@/api/platform/common/entity/pushConcernFan';
import { defHttp } from '/@/utils/http/axios';
import { PushChatMessage } from '/@/api/platform/common/entity/pushChatMessage';

enum Api {
  list = '/common_proxy/common/pushConcernFan/list',
  listFriend = '/common_proxy/common/pushConcernFan/listFriend',
  get = '/common_proxy/common/pushConcernFan/getById',
  add = '/common_proxy/common/pushConcernFan/save',
  edit = '/common_proxy/common/pushConcernFan/update',
  del = '/common_proxy/common/pushConcernFan/remove',
  updateAuditStatus = '/common_proxy/common/pushConcernFan/updateAuditStatus',
  rejectAuth = '/common_proxy/common/pushConcernFan/rejectAuth',
  getByConcernUserIdAndFanUserId = '/common_proxy/common/pushConcernFan/getByConcernUserIdAndFanUserId',
  concernFanMessageSend = '/common_proxy/common/pushConcernFan/concernFanSend',
}

export const listPushConcernFan = (params?: Partial<PushConcernFanParams>) => defHttp.get<PushConcernFanResult>({ url: Api.list, params }, { isReturnResultResponse: true });

export const listPushFriend = (params?: Partial<PushConcernFanParams>) => defHttp.get<PushConcernFanResult>({ url: Api.listFriend, params }, { isReturnResultResponse: true });

export const addPushConcernFan = (params: Partial<PushConcernFan>) => defHttp.post({ url: Api.add, data: params });

export const editPushConcernFan = (params: Partial<PushConcernFan>) => defHttp.put({ url: Api.edit, data: params });

export const getPushConcernFan = (id: string, dynamicJoinType?: string) => defHttp.get<PushConcernFan>({ url: Api.get, params: { id, dynamicJoinType } });

export const delPushConcernFan = (ids: string) => defHttp.delete({ url: `${Api.del}/${ids}` });

export const updateAuditStatus = (id: string, status: number) => defHttp.put({ url: `${Api.updateAuditStatus}/${id}/${status}` });

export const rejectAuthPushConcernFan = (ids: string) => defHttp.put({ url: `${Api.rejectAuth}/${ids}` });

export const getByConcernUserIdAndFanUserId = (concernUserId: string, fanUserId: string) => defHttp.get<PushConcernFan>({ url: Api.getByConcernUserIdAndFanUserId, params: { concernUserId, fanUserId } });

export const concernFanMessageSend = (params: Partial<PushChatMessage>) => defHttp.post({ url: Api.concernFanMessageSend, data: params });
