/**
 * 提供api模板规范代码参考,请尽量保证编写代码风格跟模板规范代码一致
 * Copyright © 2023-2023 <a href="https://godolphinx.org">海豚生态开源社区</a> All rights reserved.
 * author wangxiang4
 */

import type { Captcha, LoginParams, TokenEnhancer } from '../entity/user';
import { KiccUser } from '/@/api/common/base/entity';
import { encryptionLogin } from '/@/utils/cipher';
import { defHttp } from '/@/utils/http/axios';
import qs from 'qs';

export enum Api {
  login = '/auth_proxy/oauth/token',
  logout = '/auth_proxy/token/logout',
  getUserInfo = '/system_proxy/system/user/info',
  getCaptcha = '/code',
  checkToken = '/auth_proxy/oauth/check_token'
}

/** 用户登录接口 */
export const login = (params: LoginParams) => {
  // 非对称密钥AES加密处理
  const user =  encryptionLogin({
    data: params,
    key: import.meta.env['VITE_GATEWAY_ASE_ENCODE_SECRET'],
    param: ['password']
  });

  const { username, password, options, ...exOauthParams} = user;
  const grant_type = 'password';
  const scope = 'server';

  const data = qs.stringify({ 'username': username.trim(), 'password': password });
  return defHttp.post<TokenEnhancer>({
    url: Api.login,
    headers: {
      'Content-Type': 'application/x-www-form-urlencoded; charset=utf-8'
    },
    params: { ...exOauthParams, grant_type, scope },
    data: data
  }, options);
};

/** 获取当前用户信息 */
export const getUserInfo = () => defHttp.get<KiccUser>({ url: Api.getUserInfo }, { retryRequest: { isOpenRetry: false } });

/** 登出 */
export const logout = () => defHttp.delete({ url: Api.logout });

/** 获取验证码 */
export const getCaptcha = () => defHttp.get<Captcha>({ url: `${Api.getCaptcha}?key=${Date.now()}` });

/** 检查token是否过期 */
export const checkToken = (token: string) => defHttp.get<TokenEnhancer>({ url: Api.checkToken, params: { token } });
