/**
 * 提供api模板规范代码参考,请尽量保证编写代码风格跟模板规范代码一致
 * Copyright © 2023-2023 <a href="https://godolphinx.org">海豚生态开源社区</a> All rights reserved.
 * author wangxiang4
 */
import type { DictDataParams, DictData, DictDataResult } from '/@/api/platform/system/entity/dictData';
import { defHttp } from '/@/utils/http/axios';

enum Api {
  list = '/system_proxy/system/dictData/list',
  add = '/system_proxy/system/dictData/save',
  get = '/system_proxy/system/dictData',
  edit = '/system_proxy/system/dictData/update',
  del = '/system_proxy/system/dictData/remove',
  getByDictType = '/system_proxy/system/dictData/dictType',
  anonymousGetDictType = '/system_proxy/system/dictData/anonymousGetDictType'
}

/** 查询字典数据列表 */
export const listDictData = (params?: Partial<DictDataParams>) => defHttp.get<DictDataResult>({ url: Api.list, params }, { isReturnResultResponse: true });

/** 新增字典数据 */
export const addDictData = (params: Partial<DictData>) => defHttp.post({ url: Api.add, data: params });

/** 修改字典数据 */
export const editDictData = (params: Partial<DictData>) => defHttp.put({ url: Api.edit, data: params });

/** 查询字典数据详细 */
export const getDictData = (id: string) => defHttp.get<DictData>({ url: `${Api.get}/${id}` });

/** 删除字典数据 */
export const delDictData = (ids: string) => defHttp.delete({ url: `${Api.del}/${ids}` });

/** 根据字典类型查询字典数据 */
export const getDataByDictType = (params: Recordable) => defHttp.get<DictData[]>({ url: Api.getByDictType, params });

/** 公开匿名查询字典数据 */
export const anonymousGetDictType = (params: Recordable) => defHttp.get<DictData[]>({ url: Api.anonymousGetDictType, params });
