/**
 * 提供api模板规范代码参考,请尽量保证编写代码风格跟模板规范代码一致
 * Copyright © 2023-2023 <a href="https://godolphinx.org">海豚生态开源社区</a> All rights reserved.
 * author wangxiang4
 */
import type { SsoUserParams, SsoUser ,SsoUserResult } from '/@/api/platform/system/entity/ssoUser';
import { defHttp } from '/@/utils/http/axios';
import { KiccUser } from '/@/api/common/base/entity';

enum Api {
  list = '/system_proxy/system/ssoUser/list',
  add = '/system_proxy/system/ssoUser/save',
  get = '/system_proxy/system/ssoUser',
  getByUserName = '/system_proxy/system/ssoUser/getByUserName',
  edit = '/system_proxy/system/ssoUser/update',
  del = '/system_proxy/system/ssoUser/remove',
  updatePwd = '/system_proxy/system/ssoUser/updatePwd',
  resetPwd='/system_proxy/system/ssoUser/resetPwd',
  updateSsoUserAndExUser = '/system_proxy/system/ssoUser/updateSsoUserAndExUser',
  selectBindSsoUserList = '/system_proxy/system/ssoUser/selectBindSsoUserList'
}

export const listSsoUser = (params?: Partial<SsoUserParams>) => defHttp.get<SsoUserResult>({ url: Api.list, params }, { isReturnResultResponse: true });

export const selectBindSsoUserList = () => defHttp.get<SsoUser[]>({ url: Api.selectBindSsoUserList });

export const addSsoUser = (params: Partial<SsoUser>) => defHttp.post({ url: Api.add, data: params });

export const editSsoUser = (params: Partial<SsoUser>) => defHttp.put({ url: Api.edit, data: params });

export const getSsoUser = (id: string) => defHttp.get<SsoUser>({ url: `${Api.get}/${id}` });

export const getSsoUserByUserName = (userName: string) => defHttp.get<SsoUser>({ url: Api.getByUserName, params: { userName } });

export const delSsoUser = (ids: string) => defHttp.delete({ url: `${Api.del}/${ids}` });

export const updatePwd = (params: Partial<SsoUser>) => defHttp.put({ url: Api.updatePwd, params });

export const resetPwd = (params: Partial<SsoUser>) => defHttp.put({ url: Api.resetPwd, data: params });

export const updateSsoUserAndExUser = (params: Partial<KiccUser>) => defHttp.put({ url: Api.updateSsoUserAndExUser, data: params });
