/**
 * 提供api模板规范代码参考,请尽量保证编写代码风格跟模板规范代码一致
 * Copyright © 2023-2023 <a href="https://godolphinx.org">海豚生态开源社区</a> All rights reserved.
 * author wangxiang4
 */
import type { UserParams, User, UserResult } from '/@/api/platform/system/entity/user';
import type { KiccUser, ResultVo } from '/@/api/common/base/entity';
import { defHttp } from '/@/utils/http/axios';

enum Api {
  list = '/system_proxy/system/user/list',
  add = '/system_proxy/system/user/save',
  get = '/system_proxy/system/user',
  edit = '/system_proxy/system/user/update',
  del = '/system_proxy/system/user/remove',
  changeStatus='/system_proxy/system/user/changeStatus',
  changeTenant='/system_proxy/system/user/changeTenant',
  resetTenant='/system_proxy/system/user/resetTenant',
  getCourierUserList= '/system_proxy/system/user/getCourierUserList',
}

/** 查询用户列表 */
export const listUser = (params?: Partial<UserParams>) => defHttp.get<UserResult>({ url: Api.list, params }, { isReturnResultResponse: true });

/** 新增用户 */
export const addUser = (params: Partial<User>) => defHttp.post({ url: Api.add, data: params });

/** 修改用户 */
export const editUser = (params: Partial<User>) => defHttp.put({ url: Api.edit, data: params });

/** 查询用户详细 */
export const getUser = (id: string) => defHttp.get<ResultVo>({ url: `${Api.get}/${id}` });

/** 删除用户 */
export const delUser = (ids: string) => defHttp.delete({ url: `${Api.del}/${ids}` });

/** 修改用户状态 */
export const changeStatus = (id: string, status: string) => defHttp.put({ url: Api.changeStatus, data: { id: id, status: status } });

/** 修改用户多租户 */
export const changeTenant = (tenantIds: string[]) => defHttp.get({ url: `${Api.changeTenant}/${tenantIds}` });

/** 还原用户多租户 */
export const resetTenant = () => defHttp.get({ url: Api.resetTenant });

/** 获取全部快递员集合 */
export const getCourierUserList = () => defHttp.get<KiccUser[]>({ url: Api.getCourierUserList });
