/**
 * 提供api模板规范代码参考,请尽量保证编写代码风格跟模板规范代码一致
 * Copyright © 2023-2023 <a href="https://godolphinx.org">海豚生态开源社区</a> All rights reserved.
 * author wangxiang4
 */
import { WorkflowModelResult, WorkflowModelParams, WorkflowModel } from '/@/api/platform/workflow/entity/workflowModel';
import { defHttp } from '/@/utils/http/axios';

enum Api {
  list = '/workflow_proxy/workflow/model/list',
  getBpmnXml = '/workflow_proxy/workflow/model/getBpmnXml',
  del = '/workflow_proxy/workflow/model/remove',
  copy = '/workflow_proxy/workflow/model/copy',
  deploy = '/workflow_proxy/workflow/model/deploy',
  save = '/workflow_proxy/workflow/model/saveModel',
  bpmnXmlDownload = '/workflow_proxy/workflow/model/bpmnXmlDownload',
}

export const listModel = (params?: Partial<WorkflowModelParams>) => defHttp.get<WorkflowModelResult>({url: Api.list, params}, { isReturnResultResponse: true });

export const getModelXml = (modelId: string) => defHttp.get<string>({url: `${Api.getBpmnXml}/${modelId}` });

export const delModel = (ids: string) => defHttp.delete({ url: `${Api.del}/${ids}` });

export const copyModel = (modelId: string)=> defHttp.post({ url: `${Api.copy}/${modelId}` });

export const deployModel = (modelId: string, category: string)=> defHttp.post({ url: Api.deploy, params: { id: modelId, category } });

export const saveModel = (modelId: string, params: Recordable)=> defHttp.post({url: `${Api.save}/${modelId}`, data: params});

export const bpmnXmlDownload = (modelId: string) => defHttp.get<BlobPart>({url: `${Api.bpmnXmlDownload}/${modelId}` });
