/**
 * 提供api模板规范代码参考,请尽量保证编写代码风格跟模板规范代码一致
 * Copyright © 2023-2023 <a href="https://godolphinx.org">海豚生态开源社区</a> All rights reserved.
 * author wangxiang4
 */
import type { ProcessDefinitionInfoResult } from '/@/api/platform/workflow/entity/processDefinitionInfo';
import type { ProcessInstanceInfoResult } from '/@/api/platform/workflow/entity/processInstanceInfo';
import type { Workflow } from '/@/api/platform/workflow/entity/workflow';
import type { ResponseEntity } from '/#/axios';
import { defHttp } from '/@/utils/http/axios';
import type { ProcessInstanceInfo } from '/@/api/platform/workflow/entity/processInstanceInfo';

enum Api {
  list = '/workflow_proxy/workflow/process/list',
  exist = '/workflow_proxy/workflow/process/exist',
  runList = '/workflow_proxy/workflow/process/runList',
  historyList = '/workflow_proxy/workflow/process/historyList',
  resource = '/workflow_proxy/workflow/process/resource',
  getFlowChart = '/workflow_proxy/workflow/process/getFlowChart',
  setProcessCategory = '/workflow_proxy/workflow/process/setProcessCategory',
  setProcessInstanceStatus = '/workflow_proxy/workflow/process/setProcessInstanceStatus',
  removeDeployment = '/workflow_proxy/workflow/process/removeDeployment',
  removeProcessInstance = '/workflow_proxy/workflow/process/removeProcessInstance',
  undoProcessInstance = '/workflow_proxy/workflow/process/undoProcessInstance',
  stopProcessInstance = '/workflow_proxy/workflow/process/stopProcessInstance',
  queryProcessStatus = '/workflow_proxy/workflow/process/queryProcessStatus',
  selfProcessInstanceList = '/workflow_proxy/workflow/process/selfProcessInstanceList',
  startProcessDefinition = '/workflow_proxy/workflow/process/startProcessDefinition',
  removeHistoryProcessIns = '/workflow_proxy/workflow/process/removeHistoryProcessIns',
}

export const listProcessDef = (params?: Recordable) => defHttp.get<ProcessDefinitionInfoResult>({ url: Api.list, params }, { isReturnResultResponse: true });

export const exist = (processDefKey: string) => defHttp.get<string>({ url: `${Api.exist}/${processDefKey}` });

export const listProcessRun = (params?: Recordable) => defHttp.get<ProcessInstanceInfoResult>({ url: Api.runList, params }, { isReturnResultResponse: true });

export const listProcessHistory = (params?: Recordable) => defHttp.get<ProcessInstanceInfoResult>({ url: Api.historyList, params }, { isReturnResultResponse: true });

export const getModelResource = (processInsId: string, fileType: string, processDefId?: string) => defHttp.get<ResponseEntity<BlobPart>>({ url: Api.historyList, params: { processInsId, fileType, processDefId } });

export const getFlowChart = (processDefId: string) => defHttp.get<string>({ url: `${Api.getFlowChart}/${processDefId}` });

export const setProcessCategory = (params?: Recordable) => defHttp.put({ url: Api.setProcessCategory, params });

export const setProcessInstanceStatus = (processDefKeys: string | string[], status: string) =>  defHttp.put({url: Api.setProcessInstanceStatus, params: { processDefKeys, status } });

export const removeDeployment = (ids: string) => defHttp.delete({ url: `${Api.removeDeployment}/${ids}` });

export const removeProcessInstance = (processDefKeys: string | string[], reason: string) => defHttp.delete({url: Api.removeProcessInstance, params: { processDefKeys, reason } });

export const undoProcessInstance = (processInsId: string) => defHttp.put({ url: `${Api.undoProcessInstance}/${processInsId}` });

export const stopProcessInstance = (processInsId: string, message: string) => defHttp.put({ url: Api.stopProcessInstance, params: { processInsId, message } });

export const queryProcessStatus = (processInsId: string) => defHttp.get<ProcessInstanceInfo>({ url: `${Api.queryProcessStatus}/${processInsId}`} );

export const selfProcessInstanceList = (params: Recordable) => defHttp.get({ url: Api.selfProcessInstanceList, params });

export const startProcessDefinition = (workflow: Partial<Workflow>) => defHttp.post({ url: Api.startProcessDefinition, data: workflow });

export const removeHistoryProcessIns = (ids: string) => defHttp.delete({ url: `${Api.removeHistoryProcessIns}${ids}` });
