/**
 * 提供api模板规范代码参考,请尽量保证编写代码风格跟模板规范代码一致
 * Copyright © 2023-2023 <a href="https://godolphinx.org">海豚生态开源社区</a> All rights reserved.
 * author wangxiang4
 */
import { Workflow } from '/@/api/platform/workflow/entity/workflow';
import { defHttp } from '/@/utils/http/axios';
import { ProcessInstanceInfoResult } from '/@/api/platform/workflow/entity/processInstanceInfo';
import { HistoryTaskInfoResult } from '/@/api/platform/workflow/entity/historyTaskInfo';

enum Api {
  list = '/workflow_proxy/workflow/task/list',
  historyFlowChangeList = '/workflow_proxy/workflow/task/historyFlowChangeList',
  historyList = '/workflow_proxy/workflow/task/historyList',
  getTaskDefinition = '/workflow_proxy/workflow/task/getTaskDefinition',
  complete = '/workflow_proxy/workflow/task/complete',
  getPaintDiagramXml = '/workflow_proxy/workflow/task/getPaintDiagramXml',
  removeTask = '/workflow_proxy/workflow/task/removeTask',
  auditTask = '/workflow_proxy/workflow/task/auditTask',
  undoTask = '/workflow_proxy/workflow/task/undoTask',
  delegateTask = '/workflow_proxy/workflow/task/delegateTask',
  claim = '/workflow_proxy/workflow/task/claim',
  cancelClaim = '/workflow_proxy/workflow/task/cancelClaim',
  transferTask = '/workflow_proxy/workflow/task/transferTask',
  rollBackTaskList = '/workflow_proxy/workflow/task/rollBackTaskList',
  rejectTask = '/workflow_proxy/workflow/task/rejectTask',
  getFlowChart = '/workflow_proxy/workflow/task/getFlowChart',
}

export const listTodoTask = (params?: Recordable) => defHttp.get<ProcessInstanceInfoResult>({ url: Api.list, params }, { isReturnResultResponse: true });

export const listHistoryFlowChange = (processInsId: string) => defHttp.get<Workflow[]>({ url: `${Api.historyFlowChangeList}/${processInsId}` });

export const listHistoryTask = (params?: Recordable) => defHttp.get<HistoryTaskInfoResult>({ url: Api.historyList, params }, { isReturnResultResponse: true });

export const getTaskDefinition = (params?: Partial<Workflow>)=> defHttp.get<Workflow>({ url: Api.getTaskDefinition, params });

export const complete = (data: Partial<Workflow>)=> defHttp.post({ url: Api.complete, data });

export const getPaintDiagramXml = (processInsId: string)=> defHttp.get({ url: `${Api.getPaintDiagramXml}/${processInsId}` });

export const removeTask = (taskId: string , reason: string ) => defHttp.delete({url: Api.removeTask, params: { taskId, reason } });

export const auditTask = (data: Partial<Workflow>)=> defHttp.post({ url: Api.auditTask, data });

export const undoTask = (data: Recordable)=> defHttp.post({ url: Api.undoTask, data });

export const delegateTask = (taskId: string, userId: string) => defHttp.post({url: Api.delegateTask, params: { taskId, userId } });

export const claim = (taskId: string)=> defHttp.post({ url: `${Api.claim}/${taskId}` });

export const cancelClaim = (taskId: string)=> defHttp.post({ url: `${Api.cancelClaim}/${taskId}` });

export const transferTask = (taskId: string, userId: string)=> defHttp.post({ url: Api.transferTask, params: { taskId, userId } });

export const rollBackTaskList = (taskId: string)=> defHttp.get<Workflow[]>({ url: `${Api.rollBackTaskList}/${taskId}` });

export const rejectTask = (data: Recordable) => defHttp.post({ url: Api.rejectTask, data });

export const getFlowChart = (processInsId: string)=> defHttp.get({ url: `${Api.getFlowChart}/${processInsId}` });
