
/**
 * @program: kicc-ui
 * @description: 地图静态数据
 * @author: wangxiang4
 * @create: 2022/5/22
 */

import { BasicColumn } from '/@/components/Table';
import { commonUpload } from '/@/api/platform/core/controller/upload';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
import type { VxeColumnProps, VxeColumnPropTypes } from 'vxe-table/types/column';
import Icon from '/@/components/Icon/index';

export interface ColumnOptions extends VxeColumnProps {
  children?: ColumnOptions[]
  slots?: VxeColumnPropTypes.Slots
}

export type MapPointType = {
  value: string;
  label: string;
  mapLng: number;
  mapLat: number;
  mapOrientation: number;
  mapNotify?: boolean;
};

/** 操作面板表格列 */
export const operatePanelColumns: BasicColumn[] = [
  {
    title: '任务名称',
    dataIndex: 'name'
  },
  {
    title: '任务类型',
    dataIndex: 'taskType',
    customRender: ({ record }) =>{
      const type = record.taskType;
      let text = '', color = '';
      switch (type) {
        case '0':
          text = '普通任务';
          color = 'green';
          break;
        case '1':
          text = '交接任务';
          color = 'red';
          break;
      }
      return h(Tag, { color: color }, () => text);
    }
  }
];

/** 普通任务表格列 */
export const taskOrdinaryColumns: BasicColumn[] = [
  {
    title: '任务名称',
    dataIndex: 'name',
    editRow: true,
    editRule: true
  },
  {
    title: '医院',
    dataIndex: 'hospitalId',
    editRow: true,
    editRule: true,
    editComponent: 'Select',
  },
  {
    title: '医检',
    dataIndex: 'orgId',
    editRow: true,
    editComponent: 'Select',
  },
  {
    title: '上传单据文件',
    dataIndex: 'receiptFileId',
    editRow: true,
    editComponent: 'Upload',
    editComponentProps: {
      multiple: true,
      maxSize: 20,
      maxNumber: 10,
      showUploadSaveBtn: true,
      showPreviewNumber: false,
      emptyHidePreview: true,
      api: commonUpload,
      accept: ['image/*']
    }
  },
  {
    title: '上传文件',
    dataIndex: 'fileId',
    editRow: true,
    editComponent: 'Upload',
    editComponentProps: {
      multiple: true,
      maxSize: 20,
      maxNumber: 10,
      showUploadSaveBtn: true,
      showPreviewNumber: false,
      emptyHidePreview: true,
      api: commonUpload,
      accept: ['image/*']
    }
  },
  // todo: 第二版功能
  /*{
    title: '要求时间',
    dataIndex: 'timeRequired',
    editRow: true,
    editComponent: 'DatePicker',
    editComponentProps: {
      valueFormat: 'YYYY-MM-DD',
      format: 'YYYY-MM-DD',
    }
  }*/
];

/** 任务预设表格列 */
export const taskPresetColumns: BasicColumn[] = [
  {
    title: '任务名称',
    dataIndex: 'name',
    editRow: true,
    editRule: true
  },
  {
    title: '医院',
    dataIndex: 'hospitalId',
    editRow: true,
    editRule: true,
    editComponent: 'Select',
  },
  {
    title: '目的地预设点',
    dataIndex: 'orgName',
  },
  {
    title: '上传单据文件',
    dataIndex: 'receiptFileId',
    editRow: true,
    editComponent: 'Upload',
    editComponentProps: {
      multiple: true,
      maxSize: 20,
      maxNumber: 10,
      showUploadSaveBtn: true,
      showPreviewNumber: false,
      emptyHidePreview: true,
      api: commonUpload,
      accept: ['image/*']
    }
  },
  {
    title: '上传文件',
    dataIndex: 'fileId',
    editRow: true,
    editComponent: 'Upload',
    editComponentProps: {
      multiple: true,
      maxSize: 20,
      maxNumber: 10,
      showUploadSaveBtn: true,
      showPreviewNumber: false,
      emptyHidePreview: true,
      api: commonUpload,
      accept: ['image/*']
    }
  },
  // todo: 第二版功能
  /*{
    title: '要求时间',
    dataIndex: 'timeRequired',
    editRow: true,
    editComponent: 'DatePicker',
    editComponentProps: {
      valueFormat: 'YYYY-MM-DD',
      format: 'YYYY-MM-DD',
    }
  }*/
];

/** 子任务预设表格列 */
export const taskPresetChildColumns: BasicColumn[] = [
  {
    title: '任务名称',
    dataIndex: 'name',
    editRow: true,
    editRule: true
  },
  {
    title: '收样员',
    dataIndex: 'courierUserId',
    editRow: true,
    editRule: true,
    editComponent: 'Select'
  },
  {
    title: '起始预设点',
    dataIndex: 'orginPresetName'
  },
  {
    title: '目的地预设点',
    dataIndex: 'destinationPresetName'
  },
  {
    title: '上传单据文件',
    dataIndex: 'receiptFileId',
    editRow: true,
    editComponent: 'Upload',
    editComponentProps: {
      multiple: true,
      maxSize: 20,
      maxNumber: 10,
      showUploadSaveBtn: true,
      showPreviewNumber: false,
      emptyHidePreview: true,
      api: commonUpload,
      accept: ['image/*']
    }
  },
  {
    title: '上传文件',
    dataIndex: 'fileId',
    editRow: true,
    editComponent: 'Upload',
    editComponentProps: {
      multiple: true,
      maxSize: 20,
      maxNumber: 10,
      showUploadSaveBtn: true,
      showPreviewNumber: false,
      emptyHidePreview: true,
      api: commonUpload,
      accept: ['image/*']
    }
  },
  // todo: 第二版功能
  /*{
    title: '要求时间',
    dataIndex: 'timeRequired',
    editRow: true,
    editComponent: 'DatePicker',
    editComponentProps: {
      valueFormat: 'YYYY-MM-DD',
      format: 'YYYY-MM-DD',
    }
  }*/
];

/** 地图标记点表格列 */
export const mapPointColumns: ColumnOptions[] = [
  {
    field: 'drag',
    width: '50px',
    align: 'center',
    slots: {
      default ({ row }) {
        return [
          <span class="drag-btn">
            <i class="vxe-icon--menu"/>
          </span>
        ];
      },
      header ({ column }) {
        return [
          <vxe-tooltip content="按住后可以上下拖动排序!">
            <Icon icon="fa6-solid:signature"/>
          </vxe-tooltip>
        ];
      }
    }
  },
  { field: 'lng', title: '经度值' },
  { field: 'lat', title: '纬度值' },
  { field: 'type',
    title: '医院类型',
    slots: {
      default ({ row }) {
        const type = row.type;
        let text = '', color = '';
        switch (type) {
          case '0':
            text = '下级医院';
            color = 'green';
            break;
          case '1':
            text = '上级医检';
            color = 'red';
            break;
        }
        return [
          <Tag color={color}>{text}</Tag>
        ];
      }
    }
  },
  { field: 'taskType',
    title: '任务类型',
    slots: {
      default ({ row }) {
        const type = row.taskType;
        let text = '', color = '';
        switch (type) {
          case '0':
            text = '普通任务';
            color = 'green';
            break;
          case '1':
            text = '交接任务';
            color = 'red';
            break;
        }
        return [
          <Tag color={color}>{text}</Tag>
        ];
      }
    }
  },
  { field: 'hospitalName', title: '医院名称' }
];
