/**
 * @program: kicc-ui
 * @description: 国际化工具
 * @author: wangxiang4
 * @create: 2022/4/10
 */

import { i18n } from '/@/locales/setupI18n';
type I18nGlobalTranslation = {
  (key: string): string;
  (key: string, locale: string): string;
  (key: string, locale: string, list: unknown[]): string;
  (key: string, locale: string, named: Record<string, unknown>): string;
  (key: string, list: unknown[]): string;
  (key: string, named: Record<string, unknown>): string;
};
type I18nTranslationRestParameters = [string, any];

function getKey(namespace: string | undefined, key: string) {
  if (!namespace) return key;
  if (key.startsWith(namespace)) return key;
  return `${namespace}.${key}`;
}

/** 国际化转换,提供i18n全部功能 */
export function useI18n(namespace?: string): { t: I18nGlobalTranslation; } {
  const normalFn = {
    t: (key: string) => getKey(namespace, key)
  };
  if (!i18n) return normalFn;
  const { t, ...methods } = i18n.global;
  const tFn: I18nGlobalTranslation = (key: string, ...arg: any[]) => {
    if (!key) return '';
    if (!key.includes('.') && !namespace) return key;
    // @ts-ignore
    return t(getKey(namespace, key), ...(arg as I18nTranslationRestParameters));
  };
  return { ...methods, t: tFn };
}

/** 国际化转换,只提供i18n简单转换功能  */
export const t = (key: string): string => useI18n().t(key);
