/**
 * @program: kicc-ui
 * @description: 多租户相关操作
 * @author: wangxiang4
 * @create: 2022/4/8
 */
import { useUserStore } from '/@/store/modules/user';
import { changeTenant, resetTenant } from '/@/api/platform/system/controller/user';

export function useTenant() {
  const userStore = useUserStore();

  // 切换多租户会改变当前系统中的数据环境
  async function changeTenantEnv(tenantIds: string[]) {
    // 更改当前后端系统中的全局多租户数据
    await changeTenant(tenantIds);
    // 更改当前前端系统中的全局多租户数据
    document.location.reload();
    return tenantIds;
  }

  // 重置多租户信息
  async function resetTenantEnv() {
    // 更改当前后端系统中的全局多租户数据
    await resetTenant();
    // 更改当前前端系统中的全局多租户数据
    document.location.reload();
  }

  return {
    userStore,
    changeTenantEnv,
    resetTenantEnv
  };
}
