import '/@/assets/styles/index.less';

// 注册windi
import 'virtual:windi.css';
import 'virtual:windi-base.css';
import 'virtual:windi-components.css';
import 'virtual:windi-utilities.css';
// 注册svg图标精灵
import 'virtual:svg-icons-register';
import App from './App.vue';
import { createApp } from 'vue';
import { initAppConfigStore } from '/@/logics/initAppConfig';
import { router, setupRouter } from '/@/router';
import { setupRouterGuard } from '/@/router/guard';
import { setupStore } from '/@/store';
import { setupGlobDirectives } from '/@/directives';
import { setupI18n } from '/@/locales/setupI18n';
import { registerGlobComp } from '/@/components';
import { isDevMode } from './utils/env';
import registerApps from '/@/qiankun';

if (isDevMode()) {
  import('ant-design-vue/dist/antd.less');
  import('vxe-table/lib/style.css');
}

async function bootstrap() {
  const app = createApp(App);

  // 配置 store
  setupStore(app);

  // 初始化内部系统配置
  initAppConfigStore();

  // 注册antd全局组件
  registerGlobComp(app);

  // 多语言配置
  await setupI18n(app);

  // 配置路由
  setupRouter(app);

  // 路由器保护
  setupRouterGuard(router);

  // 注册全局指令
  setupGlobDirectives(app);

  // 注册微服务应用
  registerApps();

  // 等待路由准备好时挂载: https://next.router.vuejs.org/api/#isready
  await router.isReady();

  app.mount('#app', true);

  // 高德地图安全配置
  // @ts-ignore todo: 临时处理这是不安全的
  window._AMapSecurityConfig = {
    securityJsCode: 'f492b056e327784b1ad953eb7467f1aa'
  };
}

void bootstrap();
