/**
 * @program: kicc-ui
 * @description: 导出路由配置
 * @author: wangxiang4
 * @create: 2022/4/9
 */

import type { AppRouteRecordRaw, AppRouteModule } from '/@/router/types';
import { REDIRECT_ROUTE, PAGE_NOT_FOUND_ROUTE } from './basic';
import { mainOutRoutes } from './mainOut';
import { PageEnum } from '/@/enums/pageEnum';
import { t } from '/@/hooks/web/useI18n';

const modules = import.meta.globEager('./modules/**/*.ts');
export const routeModuleList: AppRouteModule[] = [];

Object.keys(modules).forEach((key) => {
  const mod = (modules as Recordable)[key].default;
  if (mod) {
    const modList = Array.isArray(mod) ? [...mod] : [mod];
    routeModuleList.push(...modList);
  }
});

// 根路由
export const RootRoute: AppRouteRecordRaw = {
  path: '/',
  name: 'Root',
  redirect: PageEnum.BASE_HOME,
  meta: {
    title: 'Root',
  },
};

export const LoginRoute: AppRouteRecordRaw = {
  path: '/login',
  name: 'Login',
  //新版后台登录，如果想要使用旧版登录放开即可
  // component: () => import('/@/views/core/login/Login.vue'),
  component: () => import('/@/views/core/loginmini/MiniLogin.vue'),
  meta: {
    title: t('routes.basic.login'),
  },
};

export const SsoLoginRoute: AppRouteRecordRaw[] = [
  {
    path: '/sso/login/kics',
    name: 'kicsLogin',
    component: () => import('/@/views/system/ssoLogin/kics/index.vue'),
    meta: {
      title: t('routes.basic.login'),
    },
  },
  {
    path: '/sso/login/klab',
    name: 'klabLogin',
    component: () => import('/@/views/system/ssoLogin/klab/index.vue'),
    meta: {
      title: t('routes.basic.login'),
    },
  }
];

export const basicRoutes = [
  LoginRoute,
  RootRoute,
  ...mainOutRoutes,
  ...SsoLoginRoute,
  REDIRECT_ROUTE,
  PAGE_NOT_FOUND_ROUTE,
];
