/**
 * @program: kicc-ui
 * @description: 微应用配置存储中心
 * @author: wangxiang4
 * @create: 2023/7/22
 */
import { defineStore } from 'pinia';
import { store } from '/@/store';
import { merge } from 'lodash-es';
import { FORM_DESIGN_APP_COMPONENTS, WORKFLOW_DESIGN_APP_COMPONENTS } from '/@/enums/microAppEnum';

interface MicroAppState {
  formDesignApp: Recordable;
  workflowDesignApp: Recordable;
}

export const useMicroAppStore = defineStore({
  id: 'micro-app',
  state: (): MicroAppState => ({
    formDesignApp: {},
    workflowDesignApp: {}
  }),
  getters: {
    getFormDesignApp(): Function {
      return (component: FORM_DESIGN_APP_COMPONENTS) => this.formDesignApp[component] || {};
    },
    getWorkflowDesignApp(): Function {
      return (component: WORKFLOW_DESIGN_APP_COMPONENTS) => this.workflowDesignApp[component] || {};
    }
  },
  actions: {
    setFormDesignApp(data: Recordable): void {
      this.formDesignApp = merge(this.formDesignApp, data);
    },
    setWorkflowDesignApp(data: Recordable): void {
      this.workflowDesignApp = merge(this.workflowDesignApp, data);
    },
    resetState(): void {
      this.formDesignApp = {};
      this.workflowDesignApp = {};
    },
  }
});

// 需要在设置之外使用
export function useMicroAppStoreWithOut() {
  return useMicroAppStore(store);
}
