/**
 * @program: kicc-ui
 * @description: 加密工具类
 * @author: wangxiang4
 * @create: 2022/4/8
 */
import { encrypt, decrypt } from 'crypto-js/aes';
import { parse } from 'crypto-js/enc-utf8';
import { LoginParams } from '/@/api/platform/core/entity/user';
import * as CryptoJS from 'crypto-js';
import { encryptionLoginModel } from '/#/utils';
import pkcs7 from 'crypto-js/pad-pkcs7';
import ECB from 'crypto-js/mode-ecb';
import md5 from 'crypto-js/md5';
import UTF8 from 'crypto-js/enc-utf8';
import Base64 from 'crypto-js/enc-base64';

export interface EncryptionParams {
  key: string;
  iv: string;
}

export class AesEncryption {
  private key;
  private readonly iv;

  constructor(opt: Partial<EncryptionParams> = {}) {
    const { key, iv } = opt;
    if (key) {
      this.key = parse(key);
    }
    if (iv) {
      this.iv = parse(iv);
    }
  }

  get getOptions() {
    return {
      mode: ECB,
      padding: pkcs7,
      iv: this.iv,
    };
  }

  encryptByAES(cipherText: string) {
    return encrypt(cipherText, this.key, this.getOptions).toString();
  }

  decryptByAES(cipherText: string) {
    return decrypt(cipherText, this.key, this.getOptions).toString(UTF8);
  }

}

export function encryptByBase64(cipherText: string) {
  return UTF8.parse(cipherText).toString(Base64);
}

export function decodeByBase64(cipherText: string) {
  return Base64.parse(cipherText).toString(UTF8);
}

export function encryptByMd5(password: string) {
  return md5(password).toString();
}

/** 登录加密处理,处理后台需要解密字符串,不加密密码,我后端会解码AES会解析成乱码,你就永远无法登录系统 */
export const encryptionLogin = (params: encryptionLoginModel): LoginParams => {
  let { data, param, key } = params;
  const result = JSON.parse(JSON.stringify(data));
  param.forEach(ele => {
    const data = result[ele];
    const encryptKey= CryptoJS.enc.Latin1.parse(key);
    const iv = encryptKey;
    // 加密
    const encrypted = CryptoJS.AES.encrypt(data, encryptKey, {
      iv: iv,
      mode: CryptoJS.mode.CFB,
      padding: CryptoJS.pad.NoPadding
    });
    result[ele] = encrypted.toString();
  });
  return result;
};
