import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';

export const columns: BasicColumn[] = [
  {
    title: 'ID',
    dataIndex: 'id',
    width: 120,
  },
  {
    title: '医生姓名',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '医生职称',
    dataIndex: 'title',
    width: 120,
  },
  {
    title: '医生电话',
    dataIndex: 'phone',
    width: 120,
  },
  {
    title: '医生邮箱',
    dataIndex: 'email',
    width: 120,
  },
  {
    title: '详细地址',
    dataIndex: 'detailAddress',
    width: 120,
  },
  {
    title: '所属组织类型',
    dataIndex: 'orgType',
    width: 120,
    customRender: ({ record }) => {
      const orgType = record.orgType;
      let text = '', color = '';
      switch (orgType) {
        case '1':
          text = '医院';
          color = 'green';
          break;
        case '2':
          text = '医检';
          color = 'blue';
          break;
      }
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '状态',
    dataIndex: 'status',
    width: 100,
    customRender: ({ record }) => {
      const status = record.status;
      // 采用二进制~~取反,只要为null或者0等等一些其他的空元素都会转为0
      // 第一次取反会运算为-1,在后一次取反会运算为0
      const enable = ~~status === 0;
      const color = enable ? 'green' : 'red';
      const text = enable ? '启用' : '禁用';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 180,
  }
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '医生姓名',
    component: 'Input',
    componentProps: {
      placeholder: '请输入医生姓名',
    },
    colProps: { span: 8 },
  },
  {
    field: 'orgType',
    label: '组织类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: '医院',value: '1' },
        { label: '医检',value: '2' }
      ]
    },
    colProps: { span: 7 }
  },
  {
    field: 'dateRange',
    label: '创建时间',
    component: 'RangePicker',
    componentProps: {
      style: { width:'100%' },
      valueFormat: 'YYYY-MM-DD',
      placeholder: ['开始日期','结束日期']
    },
    colProps: { span: 8 }
  }
];

export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'name',
    label: '医生姓名',
    component: 'Input',
    required: true
  },
  {
    field: 'title',
    label: '医生职称',
    component: 'Input',
    required: true,
  },
  {
    field: 'sex',
    label: '医生性别',
    component: 'Select',
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '男', value: '0' },
        { label: '女', value: '1' },
      ]
    }
  },
  {
    field: 'phone',
    label: '医生电话',
    component: 'Input',
    rules: [
      {
        pattern: new RegExp('^1[3|4|5|6|7|8|9][0-9]\\d{8}$'),
        message: '请输入正确的手机号',
        validateTrigger: 'change',
        required: true
      }
    ],
  },
  {
    field: 'email',
    label: '医生邮箱',
    component: 'Input',
    rules: [
      {
        type: 'email',
        message: '请输入正确的邮箱',
        validateTrigger: 'change',
        required: true
      }
    ],
  },
  {
    field: 'detailAddress',
    label: '地址',
    component: 'Input',
    required: false,
  },
  {
    field: 'orgType',
    label: '所属组织类型',
    component: 'Select',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '医院', value: '1' },
        { label: '医检', value: '2' }
      ]
    },
    required: true,
  },
  {
    field: 'orgId',
    label: '所属组织',
    component: 'ApiSelect',
    componentProps: {
      resultField: 'data',
      labelField: 'name',
      valueField: 'id'
    },
    required: true
  },
  {
    field: 'status',
    label: '状态',
    component: 'RadioButtonGroup',
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '启用', value: '0' },
        { label: '禁用', value: '1' },
      ],
    },
  },
  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea',
  }
];
