import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
import { listOrg } from '/@/api/platform/common/controller/org';

export const columns: BasicColumn[] = [
  {
    title: 'ID',
    dataIndex: 'id',
    width: 120,
  },
  {
    title: '医院名',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '医院类型',
    dataIndex: 'type',
    width: 120,
    customRender: ({ record }) => {
      const type = record.type;
      let text = '', color = '';
      switch (type) {
        case '0':
          text = '其他医院';
          color = 'gray';
          break;
        case '1':
          text = '合作医院';
          color = 'green';
          break;
      }
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '联系人',
    dataIndex: 'contactName',
    width: 120,
  },
  {
    title: '联系人电话',
    dataIndex: 'contactPhone',
    width: 120,
  },
  {
    title: '联系人职称',
    dataIndex: 'contactTitle',
    width: 120,
  },
  {
    title: '支付方式',
    dataIndex: 'payment',
    width: 120,
    customRender: ({ record }) => {
      const com = record.payment;
      switch (com) {
        case '0': return '月付';
        case '1': return '预约付款';
        case '2': return '采样付款';
      }
    }
  },
  {
    title: '详细地址',
    dataIndex: 'detailAddress',
    width: 180,
  },
  {
    title: '状态',
    dataIndex: 'status',
    width: 100,
    customRender: ({ record }) => {
      const status = record.status;
      const enable = ~~status === 0;
      const color = enable ? 'green' : 'red';
      const text = enable ? '启用' : '禁用';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 180,
  }
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '医院名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入医院名称',
    },
    colProps: { span: 8 }
  },
  {
    field: 'type',
    label: '医院类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: '其他医院',value: '0' },
        { label: '合作医院',value: '1' }
      ]
    },
    colProps: { span: 7 }
  },
  {
      field: 'dateRange',
      label: '创建时间',
      component: 'RangePicker',
      componentProps: {
          style: { width:'100%' },
          valueFormat: 'YYYY-MM-DD',
          placeholder: ['开始日期','结束日期']
      },
      colProps: { span: 8 }
  }
];

export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'name',
    label: '医院名称',
    component: 'Input',
    required: true
  },
  {
    field: 'type',
    label: '医院类型',
    component: 'Select',
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '其他医院',value: '0' },
        { label: '合作医院',value: '1' },
      ]
    },
    required: true,
  },
  {
    field: 'mapOrientation',
    label: '图片旋转值',
    component: 'InputNumber',
    componentProps: {
      style: { width:'100%' },
      min: 0
    }
  },
  {
    field: 'mapLng',
    label: '位置经度值',
    component: 'InputNumber',
    componentProps: {
      style: { width:'100%' },
      min: 0
    },
    required: true
  },
  {
    field: 'mapLat',
    label: '位置纬度值',
    component: 'InputNumber',
    componentProps: {
      style: { width:'100%' },
      min: 0
    },
    required: true
  },
  {
    field: 'contactName',
    label: '联系人名称',
    component: 'Input',
    required: true
  },
  {
    field: 'contactPhone',
    label: '联系人电话',
    component: 'Input',
    rules: [
      {
        pattern: new RegExp('^1[3|4|5|6|7|8|9][0-9]\\d{8}$'),
        message: '请输入正确的手机号',
        validateTrigger: 'change',
        required: true
      }
    ],
  },
  {
    field: 'contactTitle',
    label: '联系人职称',
    component: 'Input',
    required: true
  },
  {
    field: 'payment',
    label: '支付方式',
    component: 'Select',
    required: true,
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '月付', value: '0' },
        { label: '预约付款', value: '1' },
        { label: '采样付款', value: '2' },
      ],
    }
  },
  {
    field: 'detailAddress',
    label: '详细地址',
    component: 'Input',
    required: true
  },
  {
    field: 'status',
    label: '状态',
    component: 'RadioButtonGroup',
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '启用', value: '0' },
        { label: '禁用', value: '1' },
      ],
    },
  },
  {
    field: 'orgIds',
    label: '关联机构',
    component: 'ApiSelect',
    componentProps: {
      mode: 'multiple',
      resultField: 'data',
      labelField: 'name',
      valueField: 'id',
      api: listOrg
    },
    required:true
  },
  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea'
  }
];
