import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
import { listPushType } from '/@/api/platform/common/controller/pushType';
import {listPushConcernFan} from '/@/api/platform/common/controller/pushConcernFan';
import {useUserStore} from '/@/store/modules/user';
import {PushAuditStatus} from '/@/enums/pushEnum';

const userStore = useUserStore();
const userInfoStore = userStore.getUserInfo;

/** 表格列配置 */
export const columns: BasicColumn[] = [
  {
    title: '应用名称',
    dataIndex: 'name'
  },
  {
    title: '状态',
    dataIndex: 'status',
    width: 120,
    customRender: ({record}) => {
      const status = record.status;
      const enable = ~~status === 0;
      const color = enable ? 'green' : 'red';
      const text = enable ? '开通' : '关闭';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '忽略ip',
    dataIndex: 'ignoreIp'
  },
  {
    title: '创建人',
    dataIndex: 'createByName'
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 200
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 200,
    customRender: ({record}) => {
      return  record.remarks ||  h(Tag, { color: 'red' }, () => '暂无数据');
    }
  }
];

/** 搜索表单配置 */
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '应用名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入应用名称',
    },
    colProps: { span: 6 }
  }
];

/** 表单配置 */
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'name',
    label: '应用名称',
    component: 'Input',
    required: true,
    colProps: {
      span: 24
    }
  },
  {
    field: 'ignoreIp',
    label: '忽略ip',
    component: 'Input',
    colProps: {
      span: 12
    }
  },
  {
    field: 'status',
    label: '状态',
    component: 'RadioGroup',
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '开通', value: '0' },
        { label: '停止', value: '1' }
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'userId',
    label: '推送ID',
    component: 'Input',
    componentProps: {
      disabled: true
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'messageSecret',
    label: '推送密钥',
    component: 'Input',
    componentProps: {
      disabled: true
    },
    colProps: {
      span: 12
    }
  },
  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea',
    componentProps: {
      rows: 6
    },
    colProps: {
      span: 24
    }
  }
];

/** 发送消息表单 */
export const sendFormSchema: FormSchema[] = [
  {
    field: 'userId',
    label: '推送方用户id',
    component: 'Input',
    show: false
  },
  {
    field: 'messageSecret',
    label: '推送密钥',
    component: 'Input',
    show: false
  },
  {
    field: 'remarks',
    label: '任务描述',
    component: 'Input',
    required: true,
    componentProps: {
      showCount: true,
      maxlength: 20,
    }
  },
  {
    field: 'title',
    label: '通知标题',
    component: 'Input',
    required: true,
  },
  {
    label: '通知内容',
    field: 'text',
    component: 'InputTextArea',
    required: true,
    componentProps: {
      rows: 6
    },
  },
  {
    field: 'pushTypeId',
    label: '推送类型',
    component: 'ApiSelect',
    componentProps: {
      api: listPushType,
      params: {
        size: 999
      },
      labelField: 'name',
      valueField: 'id',
      resultField: 'data'
    },
  },
  {
    field: 'phone',
    label: '手机号',
    component: 'Input',
    rules: [
      {
        pattern: new RegExp('^1[3|4|5|6|7|8|9]\\d{9}(,1[3|4|5|6|7|8|9]\\d{9})*$'),
        message: '请输入正确的手机号码!',
        validateTrigger: 'blur'
      }
    ]
  },
  {
    field: 'alias',
    label: '推送用户',
    component: 'ApiTreeSelect',
    componentProps: {
      api: listPushConcernFan,
      params: {
        status: PushAuditStatus.APPROVED,
        concernUserId: userInfoStore.id
      },
      resultField: 'data',
      treeCheckable: true,
      showCheckedStrategy: 'SHOW_PARENT',
      treeDefaultExpandAll: true,
      maxTagCount: 10,
      fieldNames: { label: 'nickName', key: 'fanUserId', value: 'fanUserId' },
      allowClear: true,
    },
  },
];
