import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
import { listPushChatGroupType } from '/@/api/platform/common/controller/pushChatGroupType';

/** 表格列配置 */
export const columns: BasicColumn[] = [
  {
    title: '聊天室名称',
    dataIndex: 'name'
  },
  {
    title: '聊天室排序',
    dataIndex: 'sort',
    width: 100
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    customRender: ({record}) => {
      return  record.remarks ||  h(Tag, { color: 'red' }, () => '暂无数据');
    }
  },
  {
    title: '创建人',
    dataIndex: 'createByName'
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 200
  }
];

/** 搜索表单配置 */
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '聊天室名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入聊天室名称',
    },
    colProps: { span: 6 }
  }
];

/** 表单配置 */
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'parentId',
    label: '上级菜单',
    component: 'TreeSelect',
    defaultValue: '0',
    required: true,
    componentProps: {
      allowClear: false,
      fieldNames: {
        label: 'name',
        key: 'id',
        value: 'id'
      },
      getPopupContainer: () => document.body
    }
  },
  {
    field: 'name',
    label: '聊天室名称',
    component: 'Input',
    required: true,
    colProps: {
      span: 24
    }
  },
  {
    field: 'sort',
    label: '聊天室排序',
    component: 'InputNumber',
    componentProps: {
      style: { width:'100%' },
      min: 0
    },
    required: true,
    colProps: {
      span: 12
    }
  },
  {
    field: 'typeId',
    label: '聊天室类型',
    component: 'ApiSelect',
    required: true,
    componentProps: {
      api: listPushChatGroupType,
      params: { size: 30 },
      labelField: 'name',
      valueField: 'id',
      resultField: 'data'
    },
    colProps: {
      span: 12
    }
  },
  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea',
    componentProps: {
      rows: 6
    },
    colProps: {
      span: 24
    }
  }
];
