import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';

/** 表格列配置 */
export const columns: BasicColumn[] = [
  {
    title: '类型名称',
    dataIndex: 'name'
  },
  {
    title: '是否审核',
    dataIndex: 'isReviewed',
    width: 80,
    customRender: ({ record }) => {
      const playSound = record?.isReviewed;
      const enable = ~~playSound === 1;
      const color = enable ? 'green' : 'red';
      const text = enable ? '是' : '否';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    customRender: ({record}) => {
      return  record.remarks ||  h(Tag, { color: 'red' }, () => '暂无数据');
    }
  },
  {
    title: '创建人',
    dataIndex: 'createByName'
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 200
  }
];

/** 搜索表单配置 */
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '类型名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入聊天室类型名称',
    },
    colProps: { span: 6 }
  }
];

/** 表单配置 */
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'name',
    label: '类型名称',
    component: 'Input',
    required: true,
    colProps: {
      span: 24
    }
  },
  {
    field: 'isReviewed',
    label: '是否审核',
    component: 'RadioGroup',
    required: true,
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' }
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea',
    componentProps: {
      rows: 6
    },
    colProps: {
      span: 24
    }
  }
];
