import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { listPushRingtone } from '/@/api/platform/common/controller/pushRingtone';
import { listPushType } from '/@/api/platform/common/controller/pushType';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';

/** 表格列配置 */
export const columns: BasicColumn[] = [
  {
    title: '通知标题',
    dataIndex: 'title'
  },
  {
    title: '通知内容',
    dataIndex: 'text'
  },
  {
    title: '播放声音',
    dataIndex: 'playSound',
    width: 80,
    customRender: ({ record }) => {
      const playSound = record?.playSound;
      const enable = ~~playSound === 0;
      const color = enable ? 'green' : 'red';
      const text = enable ? '是' : '否';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '震动',
    dataIndex: 'playVibrate',
    width: 80,
    customRender: ({ record }) => {
      const playVibrate = record?.playVibrate;
      const enable = ~~playVibrate === 0;
      const color = enable ? 'green' : 'red';
      const text = enable ? '是' : '否';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '闪光',
    dataIndex: 'playLights',
    width: 80,
    customRender: ({ record }) => {
      const playLights = record?.playLights;
      const enable = ~~playLights === 0;
      const color = enable ? 'green' : 'red';
      const text = enable ? '是' : '否';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '文字转语音',
    dataIndex: 'playToText',
    width: 120,
    customRender: ({ record }) => {
      const playToText = record?.playToText;
      const enable = ~~playToText === 1;
      const color = enable ? 'green' : 'red';
      const text = enable ? '是': '否';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '离线铃声',
    dataIndex: 'sound'
  },
  {
    title: '自定义通知传输数据',
    dataIndex: 'custom'
  },
];

/** 搜索表单配置 */
export const searchFormSchema: FormSchema[] = [
  {
    field: 'title',
    label: '通知标题',
    component: 'Input',
    componentProps: {
      placeholder: '请输入通知标题',
    },
    colProps: { span: 6 }
  }
];

/** 表单配置 */
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'aliasType',
    label: '别名类型',
    component: 'Input',
    colProps: {
      span: 12
    },
  },
  {
    field: 'alias',
    label: '推送别名',
    component: 'Input',
    colProps: {
      span: 12
    }
  },
  {
    field: 'title',
    label: '通知标题',
    component: 'Input',
    colProps: {
      span: 12
    }
  },
  {
    field: 'text',
    label: '通知内容',
    component: 'Input',
    colProps: {
      span: 12
    },
  },
  {
    field: 'playSound',
    label: '播放声音',
    component: 'RadioGroup',
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' },
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'playVibrate',
    label: '震动',
    component: 'RadioGroup',
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' },
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'playLights',
    label: '闪光',
    component: 'RadioGroup',
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' },
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'playToText',
    label: '文字转语音',
    component: 'RadioGroup',
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' }
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'sound',
    label: '离线铃声',
    component: 'Input',
    componentProps: {
      placeholder: '格式为R.raw.[sound]',
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'custom',
    label: '自定义通知传输数据',
    component: 'InputTextArea',
    componentProps: {
      rows: 6
    },
  },
];
