import {FormSchema} from '/@/components/Form';
import {listPushType} from '/@/api/platform/common/controller/pushType';
import {listPushConcernFan} from '/@/api/platform/common/controller/pushConcernFan';
import {PushAuditStatus} from '/@/enums/pushEnum';
import {useUserStore} from '/@/store/modules/user';

const userStore = useUserStore();
const userInfoStore = userStore.getUserInfo;

/** 粉丝用户发送消息表单 */
export const fanSendFormSchema: FormSchema[] = [
  {
    field: 'userId',
    label: '推送方用户id',
    component: 'Input',
    defaultValue: userInfoStore.id,
    show: false
  },
  {
    field: 'remarks',
    label: '任务描述',
    component: 'Input',
    required: true,
    componentProps: {
      showCount: true,
      maxlength: 20,
    }
  },
  {
    field: 'title',
    label: '通知标题',
    component: 'Input',
    required: true,
  },
  {
    label: '通知内容',
    field: 'text',
    component: 'InputTextArea',
    required: true,
    componentProps: {
      rows: 6
    },
  },
  {
    field: 'pushTypeId',
    label: '推送类型',
    component: 'ApiSelect',
    componentProps: {
      api: listPushType,
      params: {
        size: 999
      },
      labelField: 'name',
      valueField: 'id',
      resultField: 'data'
    },
  },
  {
    field: 'alias',
    label: '推送用户',
    component: 'ApiTreeSelect',
    componentProps: {
      api: listPushConcernFan,
      params: {
        status: PushAuditStatus.APPROVED,
        concernUserId: userInfoStore.id
      },
      resultField: 'data',
      treeCheckable: true,
      showCheckedStrategy: 'SHOW_PARENT',
      treeDefaultExpandAll: true,
      maxTagCount: 10,
      fieldNames: { label: 'nickName', key: 'fanUserId', value: 'fanUserId' },
      allowClear: true,
    },
  },
];
