import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
import { SystemUserTypeMap } from '/@/enums/permissionEnum';

/** 表格列配置 */
export const columns: BasicColumn[] = [
  {
    title: '用户昵称',
    dataIndex: 'nickName',
    width: 120
  },
  {
    title: '性别',
    dataIndex: 'sex',
    width: 80,
    customRender: ({ record }) => {
      const sex = record.sex;
      const enable = ~~sex === 0;
      const color = enable ? '#6AB5F9' : '#F087BD';
      const text = enable ? '男' : '女';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '机构名称',
    dataIndex: 'deptName',
    width: 200
  },
  {
    title: '邮箱',
    dataIndex: 'email',
    width: 120
  },
  {
    title: '手机号码',
    dataIndex: 'phone',
    width: 200
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 180
  }
];

/** 搜索表单配置 */
export const searchFormSchema: FormSchema[] = [
  {
    field: 'nickName',
    label: '用户昵称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入用户昵称',
    },
    colProps: { span: 8 }
  }
];

/** 用户表单配置 */
export const userFormSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'nickName',
    label: '用户昵称',
    component: 'Input',
    colProps: {
      span: 12
    }
  },
  {
    field: 'deptId',
    label: '归属机构',
    component: 'TreeSelect',
    componentProps: {
      fieldNames: {
        label: 'name',
        key: 'deptId',
        value: 'deptId'
      },
      getPopupContainer: () => document.body
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'phone',
    label: '手机号',
    component: 'Input',
  },
  {
    field: 'email',
    label: '邮箱',
    component: 'Input',
  },
  {
    field: 'sex',
    label: '性别',
    component: 'Select',
    componentProps: {
      options: [
        { label: '男', value: '0' },
        { label: '女', value: '1' }
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'userType',
    label: '用户类型',
    component: 'Select',
    required: true,
    componentProps: {
      options: Array.from(SystemUserTypeMap, ([key, value]) => ({ label: value, value: key }))
    },
    colProps: {
      span: 12
    }
  },
  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea',
    componentProps: {
      rows: 6
    }
  }
];
