import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { useGlobSetting } from '/@/hooks/setting';
import { Button, Tag } from 'ant-design-vue';
import { commonUpload } from '/@/api/platform/core/controller/upload';
import { encodeURL } from 'js-base64';
import { getCloudProxyUrl } from '/@/utils';
const { filePreviewUrl = '' } = useGlobSetting();

/** 表格列配置 */
export const columns: BasicColumn[] = [
  {
    title: '铃声名称',
    dataIndex: 'name',
    align: 'left',
    ellipsis: true,
    width: 180,
    customRender: ({ record }) => {
      const url = encodeURL(`${getCloudProxyUrl()}${record.ringtone}`);
      return h(Button, {
          type: 'link',
          target: '_blank',
          href: `${filePreviewUrl}/onlinePreview?url=${encodeURIComponent(url)}` }, () => record.name);
    }
  },
  {
    title: '铃声地址',
    dataIndex: 'ringtone',
    width: 260,
  },
  {
    title: '创建人',
    dataIndex: 'createByName'
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 200
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 200,
    customRender: ({record}) => {
      return  record.remarks ||  h(Tag, { color: 'red' }, () => '暂无数据');
    }
  }
];

/** 搜索表单配置 */
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '铃声名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入铃声名称',
    },
    colProps: { span: 6 }
  }
];

/** 表单配置 */
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'name',
    label: '铃声名称',
    component: 'Input',
    required: true,
    colProps: {
      span: 12
    }
  },
  {
    field: 'ringtone',
    label: '上传铃声',
    component: 'Upload',
    required: true,
    componentProps: {
      multiple: false,
      maxSize: 20,
      maxNumber: 1,
      showUploadSaveBtn: true,
      showPreviewNumber: true,
      emptyHidePreview: true,
      api: commonUpload,
      accept: ['audio/*']
    }
  },
  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea',
    componentProps: {
      rows: 6
    },
    colProps: {
      span: 24
    }
  }
];

