import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Switch, Tag } from 'ant-design-vue';
import { useMessage } from '/@/hooks/web/useMessage';
import { setDefaultType } from '/@/api/platform/common/controller/pushType';
const { createConfirm, createMessage } = useMessage();

/** 表格列配置 */
export const columns = (refreshPushType: Function) => [
  {
    title: '类型名称',
    dataIndex: 'name'
  },
  {
    title: '默认类型',
    dataIndex: 'defaultType',
    width: 120,
    customRender: ({ record }) => {
      // 设置请求加载状态标识
      if (!Reflect.has(record, 'pendingStatus')) {
        record.pendingStatus = false;
      }
      return h(Switch, {
        checked: record.defaultType === '1',
        checkedChildren: '已启用',
        unCheckedChildren: '已禁用',
        loading: record.pendingStatus,
        onChange(checked: boolean) {
          checked ? createConfirm({
            iconType: 'warning',
            title: '警告',
            content: `确认要启用${record.name}推送类型吗?`,
            onOk: async () => {
              record.pendingStatus = true;
              setDefaultType({
                id: record.id,
                concernFanId: record.concernFanId,
                defaultType: '1'
              }).then(() => {
                refreshPushType();
                createMessage.success('启用成功!');
              }).catch(() => {
                createMessage.error('启用失败!');
              }).finally(() => record.pendingStatus = false);
            }
          }) : createMessage.error('不允许禁用!');
        }
      });
    }
  },
  {
    title: '播放声音',
    dataIndex: 'playSound',
    width: 80,
    customRender: ({ record }) => {
      const playSound = record?.playSound;
      const enable = ~~playSound === 1;
      const color = enable ? 'green' : 'red';
      const text = enable ? '是' : '否';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '震动',
    dataIndex: 'playVibrate',
    width: 80,
    customRender: ({ record }) => {
      const playVibrate = record?.playVibrate;
      const enable = ~~playVibrate === 1;
      const color = enable ? 'green' : 'red';
      const text = enable ? '是' : '否';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '闪光',
    dataIndex: 'playLights',
    width: 80,
    customRender: ({ record }) => {
      const playLights = record?.playLights;
      const enable = ~~playLights === 1;
      const color = enable ? 'green' : 'red';
      const text = enable ? '是' : '否';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '文字转语音',
    dataIndex: 'playToText',
    width: 120,
    customRender: ({ record }) => {
      const playToText = record?.playToText;
      const enable = ~~playToText === 1;
      const color = enable ? 'green' : 'red';
      const text = enable ? '是': '否';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '创建人',
    dataIndex: 'createByName'
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 200
  }
] as BasicColumn[];

/** 搜索表单配置 */
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '类型名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入类型名称',
    },
    colProps: { span: 6 }
  }
];

/** 表单配置 */
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'name',
    label: '类型名称',
    component: 'Input',
    required: true,
    colProps: {
      span: 24
    }
  },
  {
    field: 'playSound',
    label: '播放声音',
    component: 'RadioGroup',
    required: true,
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' }
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'playVibrate',
    label: '震动',
    component: 'RadioGroup',
    required: true,
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' }
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'playLights',
    label: '闪光',
    component: 'RadioGroup',
    required: true,
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' }
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'playToText',
    label: '文字转语音',
    component: 'RadioGroup',
    required: true,
    defaultValue: '0',
    componentProps: {
      options: [
        { label: '否', value: '0' },
        { label: '是', value: '1' }
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'offlineRingtone',
    label: '离线铃声',
    component: 'Input',
    componentProps: {
      placeholder: '格式为R.raw.[sound]',
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'onlineRingtone',
    label: '在线铃声',
    component: 'ApiSelect',
    componentProps: {
      labelField: 'name',
      valueField: 'id',
      resultField: 'data'
    },
  },
];
