import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';

/** 表格列配置 */
export const columns: BasicColumn[] = [
  {
    title: '头像',
    dataIndex: 'avatar',
    width: 120,
  },
  {
    title: '用户名',
    dataIndex: 'userName',
    width: 120
  },
  {
    title: '昵称',
    dataIndex: 'nickName',
    width: 120
  },
  {
    title: '性别',
    dataIndex: 'sex',
    width: 80,
    customRender: ({ record }) => {
      const sex = record.sex;
      const enable = ~~sex === 0;
      const color = enable ? '#6AB5F9' : '#F087BD';
      const text = enable ? '男' : '女';
      return h(Tag, { color: color }, () => text);
    }
  },
  {
    title: '邮箱',
    dataIndex: 'email',
    width: 200,
    customRender: ({record}) => {
      return  record.email ||  h(Tag, { color: 'warning' }, () => '暂无邮箱');
    }
  },
  {
    title: '手机号',
    dataIndex: 'phone',
    width: 200,
    customRender: ({record}) => {
      return  record.phone ||  h(Tag, { color: 'warning' }, () => '暂无手机号');
    }
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 180
  }
];

/** 搜索表单配置 */
export const searchFormSchema: FormSchema[] = [
  {
    field: 'userName',
    label: '用户名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入用户名称',
    },
    colProps: { span: 8 }
  },
  {
    field: 'dateRange',
    label: '创建时间',
    component: 'RangePicker',
    componentProps: {
      style: { width:'100%' },
      valueFormat: 'YYYY-MM-DD',
      placeholder: ['开始日期','结束日期']
    },
    colProps: { span: 8 }
  }
];

/** 用户表单配置 */
export const userFormSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'nickName',
    label: '昵称',
    component: 'Input',
    required: true
  },
  {
    field: 'userName',
    label: '用户名',
    component: 'Input',
    required: true,
    colProps: {
      span: 12
    }
  },
  {
    field: 'sex',
    label: '性别',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        { label: '男', value: '0' },
        { label: '女', value: '1' }
      ]
    },
    colProps: {
      span: 12
    }
  },
  {
    field: 'password',
    label: '密码',
    component: 'InputPassword',
    rules: [
      {
        required: true,
        whitespace: true,
        message: '请输入密码！',
      },
      {
        pattern: new RegExp('[^\\u4e00-\\u9fa5]+'),
        type: 'string',
        message: '密码不能输入汉字！',
      },
      {
        min: 6,
        max: 32,
        message: '长度必需在6-32之间！',
      }
    ]
  },
  {
    field: 'phone',
    label: '手机号',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入手机号！',
      },
      {
        pattern: new RegExp('^1[3|4|5|6|7|8|9][0-9]\\d{8}$'),
        message: '请输入正确的手机号码!',
        validateTrigger: 'blur'
      }
    ]
  },
  {
    field: 'email',
    label: '邮箱',
    component: 'Input',
    rules: [
      {
        type: 'email',
        message: '请输入正确的邮箱地址!',
        validateTrigger: ['blur', 'change']
      }
    ]
  },
  {
    field: 'remarks',
    label: '备注',
    component: 'InputTextArea',
    componentProps: {
      rows: 6
    }
  }
];
