import { BasicColumn, FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';
import { listFormCategory } from '/@/api/platform/workflow/extension/controller/formCategory';

/** 表格列配置 */
export const columns: BasicColumn[] = [
  {
    title: '表单名称',
    dataIndex: 'name',
  },
  {
    title: '分类',
    dataIndex: ['formCategory', 'name'],
  },
  {
    title: '版本号',
    dataIndex: ['formDefinitionJson', 'version'],
    width: 200,
    customRender: ({ record }) => {
      return record.formDefinitionJson?.version ?
        h(Tag, {color: 'success'}, () => record.formDefinitionJson?.version):
        h(Tag, {color: 'red'}, () => '暂无版本号');
    }
  },
  {
    title: '状态',
    dataIndex:  ['formDefinitionJson', 'status'],
    width: 200,
    customRender: ({ record }) => {
      return  record.formDefinitionJson?.status == '1' ?
        h(Tag, { color: 'success' }, () => '已发布'):
        h(Tag, { color: 'red' }, () => '未发布');
    }
  },
  {
    title: '是否主版本',
    dataIndex: ['formDefinitionJson', 'isPrimary'],
    width: 200,
    customRender: ({ record }) => {
      return  record.formDefinitionJson?.isPrimary == '1' ?
        h(Tag, { color: 'success' }, () => '主版本'):
        h(Tag, { color: 'red' }, () => '非主版本');
    }
  },
];

/** 搜索表单配置 */
export const searchFormSchema: FormSchema[] = [
  {
    label: '表单分类',
    field: 'categoryId',
    slot: 'categoryId',
    component: 'Input',
    colProps: { span: 8 }
  },
  {
    field: 'name',
    label: '表单名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入表单名称',
    },
    colProps: { span: 8 }
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'categoryId',
    label: '表单分类',
    component: 'ApiTreeSelect',
    componentProps: {
      placeholder: '请选择分类',
      fieldNames: {
        label: 'name',
        key: 'id',
        value: 'id'
      },
      api: listFormCategory,
      listToTree: true,
    },
    required: true,
  },
  {
    field: 'name',
    label: '表单名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入表单名称',
    },
    required: true,
  },
];

export const formCategorySchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'parentId',
    label: '上级分类',
    component: 'ApiTreeSelect',
    componentProps: {
      placeholder: '请选择分类',
      fieldNames: {
        label: 'name',
        key: 'id',
        value: 'id'
      },
    },
    required: true,
  },
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入名称',
    },
    required: true,
    colProps: {
      span: 12
    }
  },
  {
    field: 'sort',
    label: '排序',
    component: 'InputNumber',
    componentProps: {
      style: { width:'100%' },
      min: 0
    },
    required: true,
    colProps: {
      span: 12
    }
  },
  {
    label: '备注',
    field: 'remarks',
    component: 'InputTextArea',
    componentProps: {
      rows: 6
    },
    colProps: {
      span: 24
    }
  }
];
