import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import {h} from 'vue';
import {Tag} from 'ant-design-vue';

/** 表格列配置 */
export const columns: BasicColumn[] = [
  {
    title: '监听器名称',
    dataIndex: 'name',
  },
  {
    title: '监听器类型',
    dataIndex: 'listenerType',
    customRender: ({ record }) => {
      const type = record.listenerType;
      return h(Tag, { color: 'processing' }, () => ~~type === 1 ? '执行监听器' : '任务监听器');
    }
  },
  {
    title: '事件',
    dataIndex: 'event',
  },
  {
    title: '值类型',
    dataIndex: 'valueType',
    customRender: ({ record }) => {
      return {'1':'类', '2':'表达式', '3':'委托表达式'}[record.valueType || '1'];
    }
  },
  {
    title: '值',
    dataIndex: 'value'
  },
];

/** 搜索表单配置 */
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '监听器名称',
    component: 'Input',
    componentProps: {
      placeholder: '请输入名称',
    },
    colProps: { span: 8 },
  }
];

/** 表单配置 */
export const formSchema: FormSchema[] = [
  {
    field: 'id',
    label: 'ID',
    component: 'Input',
    show: false
  },
  {
    field: 'name',
    label: '监听器名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'listenerType',
    label: '监听器类型',
    component: 'RadioButtonGroup',
    defaultValue: '1',
    componentProps: ({ formModel, formActionType }) => ({
      options: [
        { label: '执行监听器', value: '1' },
        { label: '任务监听器', value: '2' },
      ],
      onChange: async (e: any) => {
        let eventOptions = e == 1
            ? [
              {label: 'start', value: 'start'},
              {label: 'take', value: 'take'},
              {label: 'end', value: 'end'}
            ] : [
              {label: 'start', value: 'start'},
              {label: 'assignment', value: 'assignment'},
              {label: 'complete', value: 'complete'},
              {label: 'delete', value: 'delete'}
            ];
        if (e === undefined) {
          eventOptions = [];
        }
        formModel.event = undefined; //  reset city value
        const { updateSchema } = formActionType;
        await updateSchema({
          field: 'event',
          componentProps: {
            options: eventOptions,
          },
        });
      }
    }),
  },
  {
    field: 'event',
    label: '事件',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        { label: 'start', value: 'start' },
        { label: 'take', value: 'take' },
        { label: 'end', value: 'end' }
      ]
    }
  },
  {
    field: 'valueType',
    label: '值类型',
    component: 'RadioButtonGroup',
    defaultValue: '1',
    componentProps: ({ formModel, formActionType }) => ({
      options: [
        { label: '类', value: '1' },
        { label: '表达式', value: '2' },
        { label: '委托表达式', value: '3' },
      ],
      onChange: async (e: any) => {
        let valueLabel = {'1':'类', '2':'表达式', '3':'委托表达式'}[e || '1'];
        const { updateSchema } = formActionType;
        await updateSchema({
          field: 'value',
          label: valueLabel
        });
      }
    }),
  },
  {
    field: 'value',
    label: '类',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请填写值',
    },
  }
];
